Iter2

Struct Iter2 

pub struct Iter2 { /* private fields */ }
An iterator over a pair of tensors which have the same first dimension size. The typical use case is to iterate over batches. Each batch is a pair containing a (potentially random) slice of each of the two input tensors.

Implementations

Source

impl Iter2

pub fn f_new( xs: &Tensor, ys: &Tensor, batch_size: i64, ) -> Result<Iter2, TchError>

Returns a new iterator.

This takes as input two tensors which first dimension must match. The returned iterator can be used to range over mini-batches of data of specified size. An error is returned if xs and ys have different first dimension sizes.

Arguments
  • xs - the features to be used by the model.
  • ys - the targets that the model attempts to predict.
  • batch_size - the size of batches to be returned.
pub fn new(xs: &Tensor, ys: &Tensor, batch_size: i64) -> Iter2

Returns a new iterator.

This takes as input two tensors which first dimension must match. The returned iterator can be used to range over mini-batches of data of specified size. Panics if xs and ys have different first dimension sizes.

Arguments
  • xs - the features to be used by the model.
  • ys - the targets that the model attempts to predict.
  • batch_size - the size of batches to be returned.
pub fn shuffle(&mut self) -> &mut Iter2

Shuffles the dataset.

The iterator would still run over the whole dataset but the order in which elements are grouped in mini-batches is randomized.

pub fn to_device(&mut self, device: Device) -> &mut Iter2

Transfers the mini-batches to a specified device.

pub fn return_smaller_last_batch(&mut self) -> &mut Iter2

When set, returns the last batch even if smaller than the batch size.