Module jit

JIT interface to run model trained/saved using PyTorch Python API.

Structs

CModule
A jit PyTorch module.
Object
TrainableCModule
The trainable version of a jit PyTorch module.

Enums

IValue
Argument and output values for JIT models. These represent arbitrary values, e.g. tensors, atomic values, pairs of values, etc.

Functions

f_fuser_cuda_is_enabled
f_fuser_cuda_set_enabled
f_get_profiling_mode
Returns whether profiling mode is set or not.
f_get_tensor_expr_fuser_enabled
f_set_graph_executor_optimize
Enables or disables the graph executor optimizer for the current thread.
f_set_profiling_mode
Activates or deactivates the profiling mode.
f_set_tensor_expr_fuser_enabled
fuser_cuda_is_enabled
fuser_cuda_set_enabled
get_profiling_mode
Returns whether profiling mode is set or not.
get_tensor_expr_fuser_enabled
set_graph_executor_optimize
Enables or disables the graph executor optimizer for the current thread.
set_profiling_mode
Activates or deactivates the profiling mode.
set_tensor_expr_fuser_enabled