Module init

Variable initialization.

Enums

FanInOut
Number of features as input or output of a layer. In Kaiming initialization, choosing FanIn preserves the magnitude of the variance of the weights in the forward pass, choosing FanOut preserves this magnitude in the backward pass.
Init
Variable initializations.
NonLinearity
The non-linear function that follows this layer. ReLU is the recommended value.
NormalOrUniform

Constants

DEFAULT_KAIMING_NORMAL
DEFAULT_KAIMING_UNIFORM

Functions

f_init
Creates a new float tensor with the specified shape, device, and initialization.
init
Creates a new float tensor with the specified shape, device, and initialization.