Module dataset

Module dataset 

A simple dataset structure shared by various computer vision datasets.

Structs

Dataset

Functions

augmentation
random_crop
Pad the image using reflections and take some random crops. This expects a 4 dimension NCHW tensor and returns a tensor with an identical shape.
random_cutout
Applies cutout: randomly remove some square areas in the original images. https://arxiv.org/abs/1708.04552
random_flip
Randomly applies horizontal flips This expects a 4 dimension NCHW tensor and returns a tensor with an identical shape.