JIT interface to run model trained/saved using PyTorch Python API.
Structs
- CModule
- A jit PyTorch module.
- Object
- TrainableC
Module - The trainable version of a jit PyTorch module.
Enums
- IValue
- Argument and output values for JIT models. These represent arbitrary values, e.g. tensors, atomic values, pairs of values, etc.
Functions
- f_
fuser_ cuda_ is_ enabled - f_
fuser_ cuda_ set_ enabled - f_
get_ profiling_ mode - Returns whether profiling mode is set or not.
- f_
get_ tensor_ expr_ fuser_ enabled - f_
set_ graph_ executor_ optimize - Enables or disables the graph executor optimizer for the current thread.
- f_
set_ profiling_ mode - Activates or deactivates the profiling mode.
- f_
set_ tensor_ expr_ fuser_ enabled - fuser_
cuda_ is_ enabled - fuser_
cuda_ set_ enabled - get_
profiling_ mode - Returns whether profiling mode is set or not.
- get_
tensor_ expr_ fuser_ enabled - set_
graph_ executor_ optimize - Enables or disables the graph executor optimizer for the current thread.
- set_
profiling_ mode - Activates or deactivates the profiling mode.
- set_
tensor_ expr_ fuser_ enabled