Variable initialization.
Enums
- FanIn
Out - Number of features as input or output of a layer.
In Kaiming initialization, choosing
FanInpreserves the magnitude of the variance of the weights in the forward pass, choosingFanOutpreserves this magnitude in the backward pass. - Init
- Variable initializations.
- NonLinearity
- The non-linear function that follows this layer. ReLU is the recommended value.
- Normal
OrUniform