A simple dataset structure shared by various computer vision datasets.
Structs
Functions
- augmentation
- random_
crop - Pad the image using reflections and take some random crops. This expects a 4 dimension NCHW tensor and returns a tensor with an identical shape.
- random_
cutout - Applies cutout: randomly remove some square areas in the original images. https://arxiv.org/abs/1708.04552
- random_
flip - Randomly applies horizontal flips This expects a 4 dimension NCHW tensor and returns a tensor with an identical shape.